@@ -22,8 +22,10 @@ logconcave = function(times, covariates, aug = TRUE){
       stop("Error: non finite values supplied")
     b = rep(0, length(x))
     output = .Call('LC_CoxPH', times, times, x, b, as.integer( c(1, length(x) ) ), FALSE, augVal, augVal, as.matrix(covariates) )
-    names(output) <- c("x", "phi", "llk", "beta", "beta_Covariance")
-    output$beta_Covariance = solve(output$beta_Covariance)
+    names(output) <- c("x", "phi", "llk", "beta", "full_Hess")
+   	l_beta = length(output$beta)
+   	hess_dim = length(output$full_Hess[,1])
+    output$beta_Covariance = -solve(output$full_Hess[-hess_dim, -hess_dim])[1:l_beta, 1:l_beta]
     output[['dens']] <- exp(output$phi)
     if(recenter == FALSE)
       output[['covOffset']] <- rep(0, length(output$beta))
@@ -77,8 +79,11 @@ logconcave = function(times, covariates, aug = TRUE){
   actInds = c(minX, which(b == max(b) ) , maxX )
   inds <- make.inds(x, l,u)
   output = .Call('LC_CoxPH', l, u, x, b, as.integer(actInds), TRUE, augVal, augVal, as.matrix(covariates) )
-  names(output) <- c("x", "phi", "llk", "beta", "beta_Covariance")
-  output$beta_Covariance = solve(output$beta_Covariance)
+  names(output) <- c("x", "phi", "llk", "beta", "full_Hess")
+  l_beta = length(output$beta)
+  hess_dim = length(output$full_Hess[,1])
+  output$beta_Covariance = -solve(output$full_Hess[-hess_dim, -hess_dim])[1:l_beta, 1:l_beta]
+  output$beta_Covariance = try(-solve(output$full_Hess)[1:l_beta, 1:l_beta])
   output[['dens']] <- exp(output$phi)
   if(recenter == FALSE)
     output[['covOffset']] <- rep(0, length(output$beta))
